=====
gojot
=====


.. image:: https://img.shields.io/pypi/v/gojot.svg
        :target: https://pypi.python.org/pypi/gojot

.. image:: https://img.shields.io/travis/schollz/gojot.svg
        :target: https://travis-ci.org/schollz/gojot

.. image:: https://readthedocs.org/projects/gojot/badge/?version=latest
        :target: https://gojot.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/schollz/gojot/shield.svg
     :target: https://pyup.io/repos/github/schollz/gojot/
     :alt: Updates


A command-line journal that is distributed and encrypted, making it easy to jot notes.


* Free software: MIT license
* Documentation: https://gojot.readthedocs.io.

Install
-------

```
sudo apt-get install gpg git
echo 'no-tty' >> ~/.gnupg/gpg.conf
```

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

